#######
Credits
#######
The Microstructure Diffusion Toolbox is a model recovery toolbox primarily meant for diffusion MRI analysis.

List of contributors:

* Robbert Harms
    - Primary developer
* Alard Roebroeck
    - Advisor and Phd. supervisor
* Francisco Fritz
    - Added Relaxometry, MPM and SSFP models
    - Quality Control on first public version
* Mark Drakesmith
    - Contributed the Poisson distributed ActiveAx model


This work was (partially) sponsored by:

* ERC Starting Grant (MULTICONNECT, #639938)
* Dutch science foundation (NWO) VIDI Grant (#14637)
* Maastricht University, the Netherlands
* Brain Innovation, Maastricht, the Netherlands
